@@ -1,8 +1,9 @@
 /* -*- Mode: C; c-set-style: gnu indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+#include <config.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 
-#include "gnome-desktop-item.h"
+#include <libgnome/gnome-desktop-item.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 /*
 #include <libgnomeui/gnome-ditem-edit.h>
@@ -32,7 +33,7 @@ test_ditem (const char *file)
 	g_print ("LOCATION: |%s|\n", text);
 
 	type = gnome_desktop_item_get_entry_type (ditem);
-	g_print ("TYPE: |%d|\n", type);
+	g_print ("TYPE: |%u|\n", type);
 
 	text = gnome_desktop_item_get_string
 		(ditem, GNOME_DESKTOP_ITEM_TYPE);
